import * as echarts from "echarts";

import "./kanban.less";
import { useEffect } from "react";
import Timer from "../homeLeft/timer";
import { inject, observer } from "mobx-react";
import { Store } from "antd/es/form/interface";

const KanBan = (props: Store) => {
  const { homeStore } = props;
  const initChart = () => {
    var myChart = echarts.init(document.getElementById("yibiaopan"));
    var option = {
      series: [
        {
          type: "gauge",
          center: ["50%", "70%"],
          startAngle: 200,
          endAngle: -20,
          radius: 100,
          min: 0,
          max: 30,
          splitNumber: 12,
          itemStyle: {
            color: "#FFAB91",
          },
         
          detail: {
            valueAnimation: true,
            width: "40%",
            lineHeight: 80,
            borderRadius: 8,
            offsetCenter: [0, "10%"],
            fontSize: 20,
            fontWeight: "bolder",
            formatter: "{value} °C",
            color: "inherit",
          },
          data: [
            {
              value: 20,
            },
          ],
        },
        {
          type: "gauge",
          center: ["50%", "70%"],
          startAngle: 200,
          radius: 80,
          endAngle: 10,
          min: 0,
          max: 60,
          itemStyle: {
            color: "#FD7347"
          },
          progress: {
            show: true,
            width: 6,
          },
          pointer: {
            show: false,
          },
          axisLine: {
            show: false,
          },
          axisTick: {
            show: false,
          },
          splitLine: { show: false },
          axisLabel: { show: false },
          detail: {
            show: false,
          },
          data: [
            {
              value: 20,
            },
          ],
        },
      ],
    };
    option && myChart.setOption(option);
  };

  const guoqi = (id: string, list: any) => {
    var myChart = echarts.init(document.getElementById(id));
    var option = {
      legend: {
        top: "bottom",
        show: false,
      },
      series: [
        {
          type: "pie",
          radius: [30, 80],
          center: ["50%", "50%"],
          itemStyle: {
            borderRadius: 2,
          },
          label: {
            normal: {
              show: true,
              position: "inner",
              formatter: "{b}:{c}",
            },
          },
          data: list,
        },
      ],
    };
    option && myChart.setOption(option);
  };

  const gailan = (list) => {
    var myChart = echarts.init(document.getElementById("gailan"));
    var option = {
      xAxis: {
        type: "category",
        data: list.map((item) => item.name),
        axisLabel: {
          show: true,
          interval: 0,
          rotate: 30,
        },
      },
      grid: { top: "10%", bottom: "15%", right: "5%" },
      yAxis: {
        type: "value",
        splitLine: {
          show: false, // 去除网格线
        },
      },
      series: [
        {
          data: list.map((item) => item.value),
          type: "line",
          smooth: true,
          areaStyle: {
            opacity: 0.1,
            color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
              {
                offset: 0,
                color: "rgb(128, 255, 165)",
              },
              {
                offset: 1,
                color: "rgb(1, 191, 236)",
              },
            ]),
          },
        },
      ],
    };
    option && myChart.setOption(option);
  };
  useEffect(() => {
    initChart();
   
    homeStore.getMm().then((res) => {
      gailan(res.data?.record ?? []);
    });
    homeStore.getmmb().then((res) => {
      guoqi("yujing", [
        { value: res.data?.record?.other_num??0, name: "第三方" },
        { value: res.data?.record?.own_num??0, name: "自有" },
      ]);
      guoqi("sourece", [
        { value: res.data?.record?.jygq??0, name: "即将过期" },
        { value: res.data?.record?.gq??0, name: "已经过期" },
        { value: res.data?.record?.bgq??0, name: "未过期" },
      ]);
      guoqi("level", [
        { value: res.data?.record?.drck??0, name: "当日出库" },
        { value: res.data?.record?.drrk??0, name: "当日入库" },
      ]);
    });
    
  }, [homeStore]);
  return (
    <div style={{ marginBottom: "10px" }}>
      <div style={{ display: "flex" }} className="gutter-row">
        <div
          style={{
            flex: 1,
          }}
        >
          <div
            style={{
              height: "240px",
              width: "100%",

              backgroundColor: "rgba(37, 52, 70, 0.4)",
              border: "1px solid rgba(255, 255, 255, 0.3)",
              boxSizing: "border-box",
            }}
          >
            <p
              style={{
                backgroundColor: "#29ecb4",
                width: "100%",
                padding: "5px",
                color: "#fff",
                boxSizing: "border-box",
                fontSize: "30px",
                fontWeight: "800",
              }}
            >
              安全运行天数
            </p>
            <p
              style={{
                fontSize: "30px",
                padding: "5px",
                fontWeight: "800",
                color: "#29ecb4",
              }}
            >
              109
            </p>
            <p style={{ color: "#29ecb4", padding: "5px" }}>
              <Timer />
            </p>
          </div>
          <div className="kanban-item">
            <div>
              <div
                id="yibiaopan"
                style={{ width: "240px", height: "240px" }}
              ></div>
            </div>
          </div>
        </div>

        <div style={{ flex: 2 }}>
          <div style={{ color: "#fff", textAlign: "center" }}>暂无视频</div>
        </div>
        <div style={{ flex: 1 }}>
          <div className="kanban-item">
            <div id="yujing" style={{ width: "240px", height: "240px" }}></div>
          </div>
          <div className="kanban-item">
            <div id="level" style={{ width: "240px", height: "240px" }}></div>
          </div>
        </div>
      </div>
      <div style={{ display: "flex" }}>
        <div className="kanban-item" style={{ flex: 1 }}>
          <div id="sourece" style={{ width: "240px", height: "240px" }}></div>
        </div>
        <div className="kanban-item" style={{ flex: 3 }}>
          <div id="gailan" style={{ width: "100%", height: "240px" }}></div>
        </div>
      </div>
    </div>
  );
};

export default inject("homeStore")(observer(KanBan));
